Documentation
¶
Index ¶
- func CreateTempDir(client *ssh.Client) (string, error)
- func Execute(flag *Flag) error
- func ExecuteCommand(client *ssh.Client, cmd string, sudoPassword string) (string, error)
- func GetDockerPath(client *ssh.Client, sudoPassword string) (string, error)
- func GetSSHClient(protocol string, host string, port int, username string, password string) (*ssh.Client, error)
- func LoadImage(client *ssh.Client, filePath string, password string, dockerPath string) (string, bool, error)
- func UploadBySCP(client *ssh.Client, localPath string, remotePath string) error
- func UploadFile(client *ssh.Client, localPath string, remotePath string) error
- type Flag
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExecuteCommand ¶
ExecuteCommand 执行命令
func GetDockerPath ¶ added in v1.2.2
GetDockerPath 获取Docker路径
func GetSSHClient ¶
func GetSSHClient(protocol string, host string, port int, username string, password string) (*ssh.Client, error)
GetSSHClient 获取SSH客户端
func LoadImage ¶
func LoadImage(client *ssh.Client, filePath string, password string, dockerPath string) (string, bool, error)
LoadImage 载入镜像
func UploadBySCP ¶ added in v1.2.2
Types ¶
Click to show internal directories.
Click to hide internal directories.